summaryrefslogtreecommitdiffstats
path: root/src/noteedit.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:35:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:35:00 -0600
commit522c7294f06d294c77bc1ea7d0dec4b371c43373 (patch)
tree22e15f6e31eba6c17ce06d8e1b0de24ef8b8f002 /src/noteedit.cpp
parent2a411f53a04f815770074b633e026a141f6fa875 (diff)
downloadbasket-522c7294f06d294c77bc1ea7d0dec4b371c43373.tar.gz
basket-522c7294f06d294c77bc1ea7d0dec4b371c43373.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src/noteedit.cpp')
-rw-r--r--src/noteedit.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/noteedit.cpp b/src/noteedit.cpp
index 056e98e..bdebdb5 100644
--- a/src/noteedit.cpp
+++ b/src/noteedit.cpp
@@ -279,7 +279,7 @@ void HtmlEditor::cursorPositionChanged()
InlineEditors::instance()->richTextItalic->setChecked( textEdit()->italic() );
InlineEditors::instance()->richTextUnderline->setChecked( textEdit()->underline() );
- switch (textEdit()->tqalignment()) {
+ switch (textEdit()->alignment()) {
default:
case 1/*TQt::AlignLeft*/: InlineEditors::instance()->richTextLeft->setChecked(true); break;
case 4/*TQt::AlignCenter*/: InlineEditors::instance()->richTextCenter->setChecked(true); break;
@@ -560,7 +560,7 @@ LinkEditDialog::LinkEditDialog(LinkContent *contentNote, TQWidget *parent/*, TQK
/* Icon button: */
m_icon->setIcon(m_noteContent->icon());
int minSize = m_autoIcon->sizeHint().height();
// Make the icon button at least the same heigh than the other buttons for a better tqalignment (nicer to the eyes):
if (m_icon->sizeHint().height() < minSize)
m_icon->setFixedSize(minSize, minSize);
else
@@ -678,7 +678,7 @@ void LinkEditDialog::slotOk()
m_icon->setIconSize(linkLook->iconSize()); // So I store it's name and reload it after size change !
m_icon->setIcon(icon);
int minSize = m_autoIcon->sizeHint().height();
// Make the icon button at least the same heigh than the other buttons for a better tqalignment (nicer to the eyes):
if (m_icon->sizeHint().height() < minSize)
m_icon->setFixedSize(minSize, minSize);
else
@@ -712,7 +712,7 @@ LauncherEditDialog::LauncherEditDialog(LauncherContent *contentNote, TQWidget *p
/* Icon button: */
m_icon->setIcon(service.icon());
int minSize = guessButton->sizeHint().height();
// Make the icon button at least the same heigh than the other buttons for a better tqalignment (nicer to the eyes):
if (m_icon->sizeHint().height() < minSize)
m_icon->setFixedSize(minSize, minSize);
else
@@ -560,7 +560,7 @@ LinkEditDialog::LinkEditDialog(LinkContent *contentNote, TQWidget *parent/*, TQK
m_icon->setIcon(m_noteContent->icon());
int minSize = m_autoIcon->sizeHint().height();
- // Make the icon button at least the same heigh than the other buttons for a better tqalignment (nicer to the eyes):
+ // Make the icon button at least the same heigh than the other buttons for a better alignment (nicer to the eyes):
if (m_icon->sizeHint().height() < minSize)
m_icon->setFixedSize(minSize, minSize);
@@ -678,7 +678,7 @@ void LinkEditDialog::slotOk()
m_icon->setIcon(icon);
int minSize = m_autoIcon->sizeHint().height();
- // Make the icon button at least the same heigh than the other buttons for a better tqalignment (nicer to the eyes):
+ // Make the icon button at least the same heigh than the other buttons for a better alignment (nicer to the eyes):
if (m_icon->sizeHint().height() < minSize)
m_icon->setFixedSize(minSize, minSize);
@@ -712,7 +712,7 @@ LauncherEditDialog::LauncherEditDialog(LauncherContent *contentNote, TQWidget *p
m_icon->setIcon(service.icon());
int minSize = guessButton->sizeHint().height();
- // Make the icon button at least the same heigh than the other buttons for a better tqalignment (nicer to the eyes):
+ // Make the icon button at least the same heigh than the other buttons for a better alignment (nicer to the eyes):
if (m_icon->sizeHint().height() < minSize)
m_icon->setFixedSize(minSize, minSize);